var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');

var MyappGenerator = yeoman.Base.extend({
    initializing: function () {
        this.pkg = require('../../package.json');
    },
    
    prompting: function () {
        var done = this.async();
        
        if (!this.options['skip-welcome-message']) {
            this.log(yosay('Allo, I\'ll generate a basic ASP.NET Core application created by Janshair Khan.'));
        }
        
        var prompts = [{
            name: 'appName',
            message: 'What is your app\'s name ?',
            default: 'App'
        }];
        
        this.prompt(prompts, function (props) {
            this.appName = props.appName;
            done();
        }.bind(this));
    },
    
    projectfiles: function () {
        //Directory root level files
        this.copy('_appsettings.json', 'appsettings.json');
        this.copy('_project.json', 'project.json');
        this.copy('_Startup.cs', 'Startup.cs');
        this.copy('_bower.json', 'bower.json');
        this.copy('bowerrc', '.bowerrc');
        this.copy('_Program.cs', 'Program.cs');
        
        //WebRoot Files
        this.copy('wwwroot/__references.js', 'wwwroot/_references.js');
        this.copy('wwwroot/_favicon.ico', 'wwwroot/favicon.ico');
        this.copy('wwwroot/js/_site.js', 'wwwroot/js/site.js');
        this.copy('wwwroot/css/_bootstrap.min.css', 'wwwroot/css/bootstrap.min.css');
        this.copy('wwwroot/css/_site.css', 'wwwroot/css/site.css');
        
        //Razor Views
        this.copy('Views/__ViewImports.cshtml', 'Views/_ViewImports.cshtml');
        this.copy('Views/__ViewStart.cshtml', 'Views/_ViewStart.cshtml');
        
        this.copy('Views/Shared/__Layout.cshtml', 'Views/Shared/_Layout.cshtml');
        this.copy('Views/Shared/__LoginPartial.cshtml', 'Views/Shared/_LoginPartial.cshtml');
        this.copy('Views/Shared/__ValidationScriptsPartial.cshtml', 'Views/Shared/_ValidationScriptsPartial.cshtml');
        
        this.copy('Views/Home/_About.cshtml', 'Views/Home/About.cshtml');        
        this.copy('Views/Home/_Contact.cshtml', 'Views/Home/Contact.cshtml');        
        this.copy('Views/Home/_Index.cshtml', 'Views/Home/Index.cshtml');
        
        this.copy('Views/Account/_Register.cshtml', 'Views/Account/Register.cshtml');      
        this.copy('Views/Account/_Login.cshtml', 'Views/Account/Login.cshtml');      
        
        //Controllers
        this.copy('Controllers/_AccountController.cs', 'Controllers/AccountController.cs');      
        this.copy('Controllers/_HomeController.cs', 'Controllers/HomeController.cs');
        
        //ViewModels        
        this.copy('Models/AccountViewModels/_LoginViewModel.cs', 'Models/AccountViewModels/LoginViewModel.cs');
        this.copy('Models/AccountViewModels/_RegisterViewModel.cs', 'Models/AccountViewModels/RegisterViewModel.cs');
    },
    
    end: function () {
        this.bowerInstall();
        
        this.log('You have created your project successfully, type the following commands to run the application');
        this.log();
        this.log('dotnet restore');
        this.log('dotnet run');
        this.log();
    }
});

module.exports = MyappGenerator;
